@@ -2,7 +2,7 @@ package Myriad::Registry;
 
 use Myriad::Class extends => 'IO::Async::Notifier';
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 =encoding utf8
@@ -50,7 +50,8 @@ async method add_service (%args) {
     weaken(my $myriad = delete $args{myriad});
 
     my $pkg = blessed($srv) ? ref $srv : $srv;
-    my $service_name = delete $args{name} // $self->make_service_name($pkg);
+    my $namespace = delete $args{namespace};
+    my $service_name = delete $args{name} // $self->make_service_name($pkg, $namespace);
 
     $srv = $srv->new(
         %args,
@@ -217,9 +218,20 @@ method receivers_for ($pkg) {
 Reformat a given string to make it combatible with our services
 naming strategy
 
+it takes the following args:
+
+=over 4
+
+=item * name - a String with the original name
+
+=item * namespace - If available the service name will not contain the namespace
+
+=back
+
 =cut
 
-method make_service_name ($name) {
+method make_service_name ($name, $namespace = '') {
+    $name =~ s/^\Q$namespace// if $namespace;
     return lc($name) =~ s{::}{.}gr
 }
 
